package cn.fw.shirasawa.common.utils;

import cn.hutool.core.date.BetweenFormater;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.temporal.TemporalAccessor;
import java.util.Calendar;
import java.util.Date;

/**
 * 日期处理工具
 * <p>
 *
 * @author kurisu
 */
public final class DateUtil extends cn.hutool.core.date.DateUtil {

    /**
     * 默认构造器
     */
    private DateUtil() {
        throw new UnsupportedOperationException();
    }


    /**
     * 处理日期，保留年月日
     */
    public static LocalDate date2LocalDate(final Date date) {
        if (date == null) {
            return null;
        }
        return toLocalDateTime(date).toLocalDate();
    }

    public static LocalDateTime date2LocalDateTime(final Date date) {
        if (date == null) {
            return null;
        }
        return toLocalDateTime(date);
    }

    /**
     * convert LocalDateTime to Date
     */
    public static Date toDate(final TemporalAccessor dateTime) {
        return date(dateTime).toJdkDate();
    }


    public static Date getBeginInTime(Date inTime) {
        if (inTime == null) {
            return null;
        }
        Calendar c = Calendar.getInstance();
        c.setTime(inTime);
        c.set(Calendar.HOUR_OF_DAY, 0);
        c.set(Calendar.MINUTE, 0);
        c.set(Calendar.SECOND, 0);
        return c.getTime();
    }

    public static Date getEndInTime(Date inTime) {
        if (inTime == null) {
            return null;
        }
        Calendar c = Calendar.getInstance();
        c.setTime(inTime);
        c.set(Calendar.HOUR_OF_DAY, 23);
        c.set(Calendar.MINUTE, 59);
        c.set(Calendar.SECOND, 59);
        return c.getTime();
    }

    /**
     * 获取时间字符串
     *
     * @param date    需要转换格式的日期
     * @param pattern 时间字符串格式
     * @return 返回时间字符串
     */
    public static String getFormatString(Date date, String pattern) {
        return getFormatString(date, pattern, "");
    }

    public static String getFormatString(Date date, String pattern, String defaultStr) {
        if (date == null) {
            return defaultStr;
        }
        SimpleDateFormat format = new SimpleDateFormat(pattern);
        return format.format(date);
    }


    /**
     * 判断两个时间段是否有交集
     *
     * @param startTime    开始时间1
     * @param endTime      结束时间1
     * @param startTimeNew 开始时间2
     * @param endTimeNew   结束时间2
     * @return
     */
    public static boolean isInterSection(LocalDateTime startTime, LocalDateTime endTime,
                                         LocalDateTime startTimeNew, LocalDateTime endTimeNew) {
        return isInterSection(toDate(startTime),
                toDate(endTime),
                toDate(startTimeNew),
                toDate(endTimeNew)
        );
    }

    /***
     *
     * @param startDateOne 第一个时间段的开始时间
     * @param endDateOne 第一个时间段的结束时间
     * @param startDateTwo 第二个时间段的开始时间
     * @param endDateTwo 第二个时间段的结束时间
     * @return
     */
    public static Boolean isInterSection(Date startDateOne, Date endDateOne, Date startDateTwo, Date endDateTwo) {
        Date maxStartDate = startDateOne;
        if (maxStartDate.before(startDateTwo)) {
            maxStartDate = startDateTwo;
        }

        Date minEndDate = endDateOne;
        if (endDateTwo.before(minEndDate)) {
            minEndDate = endDateTwo;
        }
        return maxStartDate.before(minEndDate) || (maxStartDate.getTime() == minEndDate.getTime());
    }

    public static void main(String[] args) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date date = format.parse("2020-09-19 15:45:30");


        System.out.println(DateUtil.formatBetween(41004*1000, BetweenFormater.Level.MINUTE));
    }
}
