package cn.fw.shirasawa.dao.mapper;

import cn.fw.shirasawa.domain.db.follow.FollowRecord;
import cn.fw.shirasawa.domain.db.follow.SucessFollowRecord;
import cn.fw.shirasawa.domain.dto.FollowRecordPoolDTO;
import cn.fw.shirasawa.domain.query.FollowRecordPoolQuery;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * @author : kurisu
 * @className : FollowRecordMapper
 * @description : 跟进记录
 * @date: 2020-08-12 11:00
 */
@Repository
public interface FollowRecordMapper extends BaseMapper<FollowRecord> {

    /**
     * 获取最后几次的跟进方式
     *
     * @param taskId
     * @param userId
     * @param size
     * @return
     */
    List<Long> getLastRecordAttType(@Param("taskId") Long taskId, @Param("userId") Long userId, @Param("size") int size);


    /**
     * 根据业务类型 档案id获取已完成的跟进记录
     *
     * @param bizType
     * @param customerIdList
     * @return
     */
    List<SucessFollowRecord> getCompletedFollowRecord(@Param("bizType") Integer bizType, @Param("customerIdList") List<Long> customerIdList);


    /**
     * 查询跟进记录池数量
     *
     * @param queryVO
     * @return
     */
    Long recordPoolCount(@Param("condition") FollowRecordPoolQuery queryVO);

    /**
     * 查询跟进记录池数据
     *
     * @param startIndex
     * @param pageSize
     * @param queryVO
     * @return
     */
    List<FollowRecordPoolDTO> recordPoolList(@Param("startIndex") Integer startIndex, @Param("pageSize") Integer pageSize, @Param("condition") FollowRecordPoolQuery queryVO);
}
