package cn.fw.shirasawa.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : ClueStatusEnum
 * @description : 线索状态
 * @date: 2020-08-11 17:37
 */
public enum ClueStatusEnum implements IEnum<Integer> {
    /**
     * 等待中
     */
    WAITING(1, "等待中"),
    /**
     * 进行中
     */
    ONGOING(2, "进行中"),
    /**
     * 已完成
     */
    COMPLETE(3, "已完成"),
    /**
     * 已失败
     */
    FAILURE(4, "已失败");

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    ClueStatusEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static ClueStatusEnum ofValue(final Integer value) {
        for (final ClueStatusEnum typeEnum : ClueStatusEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final ClueStatusEnum typeEnum : ClueStatusEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @Override
    @JsonValue
    public Integer getValue() {
        return value;
    }
}
