package cn.fw.shirasawa.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * 逾期类型
 */
public enum OutTimeEnum implements IEnum<Integer> {

    ONGOING(0,"处理中"),
    BE_COMPLETE(1,"已完成"),
    BE_SYSTEM(2,"系统完成"),
    BE_OVERDUE(3,"已逾期")
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;


    OutTimeEnum(Integer value, String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static OutTimeEnum ofValue(final Integer value) {
        for (final OutTimeEnum typeEnum : OutTimeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final OutTimeEnum typeEnum : OutTimeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }
}
