package cn.fw.shirasawa.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : SendStatusEnum
 * @description : 消息提醒发送状态
 * @date: 2020-08-11 17:37
 */
public enum SendStatusEnum implements IEnum<Integer> {
    /**
     * 未发送
     */
    NOT_SENT(1, "未发送"),
    /**
     * 发送成功
     */
    SUCCESS(2, "发送成功"),
    /**
     * 发送失败
     */
    FAILED(3, "发送失败");

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    SendStatusEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static SendStatusEnum ofValue(final Integer value) {
        for (final SendStatusEnum typeEnum : SendStatusEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final SendStatusEnum typeEnum : SendStatusEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }
}
