package cn.fw.shirasawa.domain.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : DefeatTypeEnum
 * @description : 战败类型
 * @date: 2020-10-16 17:56
 */
public enum TaskDefeatTypeEnum implements IEnum<Integer> {
    /**
     * 申请战败
     */
    A(1, "申请战败"),
    /**
     * 到期划走
     */
    B(2, "到期划走"),
    /**
     * 到期战败
     */
    C(3, "到期战败"),
    /**
     * 角色调整变更
     */
    D(4, "角色调整变更"),
    /**
     * 系统战败
     */
    E(5, "系统战败"),
    /**
     * 到另一门店
     */
    F(6, "到另一门店"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    TaskDefeatTypeEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static TaskDefeatTypeEnum ofValue(final Integer value) {
        for (final TaskDefeatTypeEnum typeEnum : TaskDefeatTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }

    /**
     * 获取描述
     *
     * @return 值
     */
    @JsonCreator
    public static String getNameByVale(final Integer value) {
        for (final TaskDefeatTypeEnum typeEnum : TaskDefeatTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }

    /**
     * 获取值
     *
     * @return 值
     */
    @JsonValue
    @Override
    public Integer getValue() {
        return value;
    }
}
