package cn.fw.shirasawa.domain.query;

import cn.fw.common.validator.EnumValue;
import cn.fw.shirasawa.common.utils.DateUtil;
import cn.fw.shirasawa.domain.enums.FollowTypeEnum;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.math.NumberUtils;
import org.springframework.util.CollectionUtils;

import javax.validation.constraints.NotNull;
import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author : kurisu
 * @className : FollowRecordPoolQuery
 * @description : 跟进记录池查询条件
 * @date: 2021-02-21 15:55
 */
@EqualsAndHashCode(callSuper = true)
@Data
@ToString(callSuper = true)
public class FollowRecordPoolQuery extends PoolQuery {
    /**
     * 客户名称
     */
    private String customerName;

    @EnumValue(enumClass = FollowTypeEnum.class, message = "跟进类型不正确")
    private Integer type;
    /**
     * 业态类型
     */
    @NotNull(message = "业态类型不能为空")
    private Integer bizType;
    /**
     * 状态
     */
    private String state;
    /**
     * 查询自己的数据
     */
    private Boolean owner;
    private String startTime;
    /**
     * 业务id 【活动编号等 全匹配】
     */
    private String bizId;
    /**
     * 数据时间 【查询时精确到月份】
     * 无时间是默认当天数据
     */
    private Date dataDate;


    public Date getStartTime1() {
        if (StringUtils.isBlank(startTime)) {
            return null;
        }
        String[] times = startTime.split(",");
        if (StringUtils.isNotBlank(times[0]) && NumberUtils.isDigits(times[0])) {
            LocalDateTime localDateTime = Instant.ofEpochMilli(NumberUtils.toLong(times[0])).atZone(ZoneId.systemDefault()).toLocalDateTime();
            return DateUtil.getBeginInTime(DateUtil.toDate(localDateTime));
        }
        return null;
    }

    public Date getStartTime2() {
        if (StringUtils.isBlank(startTime)) {
            return null;
        }
        String[] times = startTime.split(",");
        if (times.length < TIME_STR_LENGTH) {
            return null;
        }
        if (StringUtils.isNotBlank(times[1]) && NumberUtils.isDigits(times[1])) {
            LocalDateTime localDateTime = Instant.ofEpochMilli(NumberUtils.toLong(times[1])).atZone(ZoneId.systemDefault()).toLocalDateTime();
            return DateUtil.getEndInTime(DateUtil.toDate(localDateTime));
        }
        return null;
    }

    public List<Integer> getState() {
        if (StringUtils.isBlank(state)) {
            return null;
        }
        List<Integer> list = Arrays.stream(state.split(",")).filter(StringUtils::isNoneBlank).map(Integer::valueOf).collect(Collectors.toList());
        if (CollectionUtils.isEmpty(list)) {
            return null;
        }
        return list;
    }
}
