package cn.fw.shirasawa.domain.vo.pool;

import cn.fw.common.json.MaskMobilePhone;
import cn.fw.shirasawa.common.utils.StringUtils;
import cn.fw.shirasawa.domain.enums.FollowTypeEnum;
import cn.fw.shirasawa.domain.enums.OutTimeEnum;
import lombok.Data;

import java.time.LocalDateTime;
import java.util.Objects;

/**
 * 跟进记录池vo
 *
 * @author : kurisu
 * @version : 1.0
 * @className : FollowRecordPoolVO
 * @description : 跟进记录池vo
 * @date : 2022-08-03 14:21
 */
@Data
public class FollowRecordPoolVO {
    private Long id;
    /**
     * 档案id
     */
    private Long customerId;
    /**
     * 客户姓名
     */
    private String customerName;
    /**
     * 车牌号
     */
    private String plateNo;
    /**
     * 手机号
     */
    @MaskMobilePhone
    private String mobile;
    /**
     * 归属地
     */
    private String region;
    /**
     * 车架号
     */
    private String vin;
    /**
     * 跟进类型
     */
    private FollowTypeEnum type;
    /**
     * 跟进人员
     */
    private String follower;
    /**
     * 服务站
     */
    private String shopName;
    /**
     * 任务开始时间
     */
    private LocalDateTime planTime;
    /**
     * 任务完成
     */
    private LocalDateTime followTime;
    /**
     * 截止时间
     */
    private LocalDateTime deadline;
    /**
     * 完成跟进时长
     */
    private String consuming;
    /**
     * 状态 0: 进行中 1：已完成 2：系统完成 3：逾期
     */
    private OutTimeEnum state;
    /**
     * 跟进方式
     */
    private String followMode;
    /**
     * 集团id
     */
    private Long groupId;

    /**
     * 是否逾期
     *
     * @return
     */
    public boolean getOverdue() {
        if (Objects.isNull(state)) {
            return false;
        }
        return OutTimeEnum.BE_OVERDUE.equals(state);
    }


    public String getStateDesc() {
        if (Objects.isNull(state)) {
            return null;
        }
        return state.getName();
    }

    public String getTypeDesc() {
        if (Objects.isNull(type)) {
            return null;
        }
        return type.getName();
    }

    public boolean isFollowed() {
        return StringUtils.isValid(followMode);
    }
}
