package cn.fw.shirasawa.rpc.flow;

import cn.fw.approval.sdk.ApprovalApi;
import cn.fw.approval.sdk.param.InitiateApprovalParam;
import cn.fw.approval.sdk.param.WithdrawApprovalParam;
import cn.fw.approval.sdk.result.WithdrawResult;
import cn.fw.data.base.domain.common.Message;
import cn.fw.shirasawa.common.utils.DateUtil;
import cn.fw.shirasawa.common.utils.StringUtils;
import cn.fw.shirasawa.rpc.flow.dto.FlowDto;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.Collections;
import java.util.List;

import static cn.fw.common.businessvalidator.Validator.BV;


/**
 * @author kurisu
 * @description: 发起审批
 * @date 2019/9/22.
 */
@Service
@Slf4j
public class FlowApproveRpc {

    private final ApprovalApi flowApi;

    @Autowired
    public FlowApproveRpc(ApprovalApi flowApi) {
        this.flowApi = flowApi;
    }


    public String initiate(final FlowDto flowDto) {
        InitiateApprovalParam dataDto = new InitiateApprovalParam();
        BeanUtils.copyProperties(flowDto, dataDto);
        dataDto.setBriefContent(flowDto.getBriefContent());
        dataDto.setExtData(flowDto.getExtData());
        dataDto.setExpTime(DateUtil.toDate(LocalDateTime.now().plusYears(700L)));
        Message<String> msg = flowApi.initiate(dataDto);
        log.info("发起审批FlowApproveRpc.initiateApproval, 参数：[{}] 结果：{}", dataDto, msg.getResult());
        boolean success = msg.isSuccess() && StringUtils.isValid(msg.getData());
        BV.isTrue(success, msg.getResult());
        return msg.getData();
    }

    public boolean cancel(final String orderNo) {
        try {
            WithdrawApprovalParam param = new WithdrawApprovalParam();
            param.setOrderNoList(Collections.singletonList(orderNo));
            Message<List<WithdrawResult>> msg = flowApi.withdraw(param);
            log.info("取消审批FlowApproveRpc.cancelApproval, 参数：[{}] 结果：{}", orderNo, msg.getResult());
            return msg.isSuccess();
        } catch (Exception e) {
            log.error("取消审批失败, 参数：[{}]", orderNo);
            e.printStackTrace();
        }
        return false;
    }
}
