package cn.fw.shirasawa.rpc.pstn;

import cn.fw.common.exception.BusinessException;
import cn.fw.data.base.domain.common.Message;
import cn.fw.pstn.sdk.api.ISecretCallApiService;
import cn.fw.pstn.sdk.api.para.CallCondition;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.lang.NonNull;
import org.springframework.lang.Nullable;
import org.springframework.stereotype.Service;

import static org.apache.commons.lang3.StringUtils.*;

/**
 * 电话服务
 * <p>
 * create at 2019-03-09
 *
 * @author kurisu
 */
@Slf4j
@Service
public class PstnRpcService {

    /**
     * 智能通话服务
     */
    private final ISecretCallApiService secretCallApiService;

    /**
     * 默认构造器
     */
    @Autowired
    public PstnRpcService(final ISecretCallApiService secretCallApiService) {
        this.secretCallApiService = secretCallApiService;
    }

    /**
     * 获取虚拟号码
     *
     * @param call   主叫电话号码
     * @param beCall 被叫电话号码
     * @return 虚拟号码
     */
    @Nullable
    public String virtualNumber(@NonNull final String call, @NonNull final String beCall, @NonNull final Long groupId) {
        if (isAllBlank(call, beCall)) {
            return EMPTY;
        }
        CallCondition condition = CallCondition.builder()
                .staffMobile(call)
                .targetMobile(beCall)
                .groupId(groupId)
                .needDegrade(Boolean.FALSE)
                .build();
        Message<String> msg = secretCallApiService.call(condition);
        if (!msg.isSuccess()) {
            log.info("调用pstn系统拨号失败：{}", msg.getResult());
            throw new BusinessException(msg.getResult());
        }
        return isBlank(msg.getData()) ? EMPTY : msg.getData();
    }
}
