package cn.fw.shirasawa.sdk.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : BusinessTypeEnum
 * @description : 业态类型
 * @date: 2022-01-11 14:48
 */
public enum BusinessTypeEnum implements IEnum<Integer> {
    /**
     * 业态类型
     */
    PS(1, "售前"),
    AS(2, "售后"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    BusinessTypeEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static BusinessTypeEnum ofValue(final Integer value) {
        for (final BusinessTypeEnum typeEnum : BusinessTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }


    /**
     * 获取描述
     *
     * @return 值
     */
    public static String getNameByVale(final Integer value) {
        for (final BusinessTypeEnum typeEnum : BusinessTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }

    @Override
    @JsonValue
    public Integer getValue() {
        return value;
    }
}
