package cn.fw.shirasawa.sdk.enums;

import com.baomidou.mybatisplus.core.enums.IEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import lombok.Getter;

/**
 * @author : kurisu
 * @className : DataTypeEnum
 * @description : 数据类型
 * @date: 2020-08-11 17:37
 */
public enum DataTypeEnum implements IEnum<Integer> {
    /**
     * 跟进类型
     */
    FM(1, "首保"),
    RM(2, "流失客户"),
    AC(3, "事故车"),
    IR(4, "续保"),
    AF(5, "活动邀约"),
    CF(6, "集客"),
    PF(7, "潜客"),
    FA(8, "急救"),
    RV(9, "回访"),
    PL(10, "公共池跟进"),
    ;

    /**
     * 值
     */
    private final Integer value;
    /**
     * 名称
     */
    @Getter
    private final String name;

    DataTypeEnum(final Integer value, final String name) {
        this.value = value;
        this.name = name;
    }

    /**
     * 根据枚举值获取枚举对象
     */
    @JsonCreator
    public static DataTypeEnum ofValue(final Integer value) {
        for (final DataTypeEnum typeEnum : DataTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum;
            }
        }
        return null;
    }


    /**
     * 获取描述
     *
     * @return 值
     */
    public static String getNameByVale(final Integer value) {
        for (final DataTypeEnum typeEnum : DataTypeEnum.values()) {
            if (typeEnum.value.equals(value)) {
                return typeEnum.getName();
            }
        }
        return "";
    }

    @Override
    @JsonValue
    public Integer getValue() {
        return value;
    }
}
