package cn.fw.shirasawa.sdk.param;

import cn.fw.shirasawa.sdk.enums.BusinessTypeEnum;
import cn.fw.shirasawa.sdk.enums.DataTypeEnum;
import lombok.*;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.util.Date;
import java.util.Map;

/**
 * @author : kurisu
 * @className : FollowOriginalParam
 * @description : 跟进原始数据
 * @date: 2020-08-14 17:41
 */
@Data
@EqualsAndHashCode
@ToString
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class FollowGenerateDTO {
    /**
     * 数据类型
     */
    @NotNull(message = "数据类型不能为空")
    private DataTypeEnum type;
    /**
     * 业态类型
     */
    @NotNull(message = "业态类型不能为空")
    private BusinessTypeEnum businessType;
    /**
     * 档案id
     */
    private Long customerId;
    /**
     * 档案名称
     */
    private String customerName;
    /**
     * 会员id
     */
    private Long memberId;
    /**
     * 车牌号
     * 事故车的场景不能为空
     */
    private String plateNo;
    /**
     * 车架号
     */
    private String frameNo;
    /**
     * 联系方式
     * 事故车的场景不能为空
     */
    private String contacts;
    /**
     * 业务id
     */
    @NotBlank(message = "业务id不能为空")
    private String detailId;
    /**
     * 待办系统展示参数
     */
    @NotEmpty(message = "待办展示不能为空")
    private Map<String, String> noteMap;
    /**
     * 数据产生时间
     */
    private Date generateTime;
    /**
     * 截止时间
     */
    private Date deadline;
    /**
     * 首次跟进待办截止时间
     */
    private Date firstRecordDeadline;
    /**
     * 集团id
     */
    @NotNull(message = "集团id不能为空")
    private Long groupId;
    /**
     * 门店id
     */
    @NotNull(message = "门店id不能为空")
    private Long shopId;
    /**
     * 门店名称
     */
    private String shopName;
    /**
     * 跟进人员id
     */
    @NotNull(message = "跟进人员id不能为空")
    private Long userId;
    /**
     * 跟进人员名称
     */
    private String userName;
    /**
     * 是否覆盖 false-不覆盖 true-覆盖 默认不覆盖
     */
    private Boolean coverFlag;
    /**
     * 业务Id
     */
    private String bizId;
    /**
     * 二次分配数据
     */
    private Boolean secondary;
}
