package cn.fw.shirasawa.sdk.param;

import cn.fw.common.validator.EnumValue;
import cn.fw.shirasawa.sdk.enums.BusinessTypeEnum;
import cn.fw.shirasawa.sdk.enums.DataTypeEnum;
import lombok.Data;
import lombok.ToString;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.util.Date;
import java.util.Map;

/**
 * @author : kurisu
 * @className : NewRecordDTO
 * @description : 生成待办参数
 * @date: 2022-01-17 10:46
 */
@Data
@ToString
public class NewRecordDTO {
    /**
     * 业态类型
     * 1 售前 2 售后
     */
    @EnumValue(enumClass = BusinessTypeEnum.class, message = "业态类型不正确")
    private Integer businessType;
    /**
     * 档案id
     */
    private Long customerId;
    /**
     * 客户名称
     */
    private String customerName;
    /**
     * 联系方式
     */
    private String contacts;
    /**
     * 车牌号 （售后用）
     */
    private String plateNo;
    /**
     * 数据类型
     */
    private DataTypeEnum dataType;
    /**
     * 跟进人id
     */
    @NotNull(message = "跟进人员不能为空")
    private Long userId;
    /**
     * 下次跟进时间
     */
    @NotNull(message = "下次跟进日期不能为空")
    private Date nextDate;
    /**
     * 下次跟进的截止日期
     */
    @NotNull(message = "跟进截止日期不能为空")
    private Date nextDeadline;
    /**
     * 待办参数
     */
    @NotEmpty(message = "待办参数不能为空")
    private Map<String, String> noteMap;
    /**
     * 上一个跟进记录的id（优先级最高）
     */
    private Long preRecordId;
    /**
     * 二次分配
     */
    private Boolean secondary;
}
