package cn.fw.shirasawa.server.controller.task;

import cn.fw.common.cache.locker.DistributedLocker;
import cn.fw.shirasawa.domain.db.OriginalData;
import cn.fw.shirasawa.service.bus.follow.FollowBizService;
import cn.fw.shirasawa.service.data.OriginalDataService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.Getter;
import org.redisson.api.RLock;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.List;
import java.util.concurrent.locks.Lock;

/**
 * @author : kurisu
 * @className : OriginDataDealTask
 * @description : 原始数据处理
 * @date: 2020-08-18 09:29
 */
@Component
@ConditionalOnProperty(prefix = "task", name = "switch", havingValue = "on")
public class OriginDataDealTask {
    private final OriginalDataService originalDataService;
    private final FollowBizService followBizService;
    private final DistributedLocker distributedLocker;

    @Value("${spring.cache.custom.global-prefix}:origin")
    @Getter
    private String prefix;

    @Autowired
    public OriginDataDealTask(final OriginalDataService originalDataService,
                              final FollowBizService followBizService,
                              final DistributedLocker distributedLocker) {
        this.originalDataService = originalDataService;
        this.followBizService = followBizService;
        this.distributedLocker = distributedLocker;
    }

    @Scheduled(initialDelay = 1000 * 15, fixedRate = 1000 * 15)
    public void syn2Task() {
        String key = getPrefix() + ":syncdata";
        Lock lock = distributedLocker.lock(key);
        boolean locked = ((RLock) lock).isLocked();
        if (!locked) {
            return;
        }
        try {
            List<OriginalData> list = originalDataService.list(Wrappers.<OriginalData>lambdaQuery()
                    .eq(OriginalData::getSolved, Boolean.FALSE)
                    .last("limit 0,500")
            );
            if (CollectionUtils.isEmpty(list)) {
                return;
            }
            for (OriginalData data : list) {
                data.setSolved(followBizService.origin2task(data));
            }
            originalDataService.updateBatchById(list);
        } finally {
            distributedLocker.unlock(lock);
        }
    }
}
