package cn.fw.shirasawa.component;

import cn.fw.approval.sdk.mq.ApprovalResult;
import cn.fw.shirasawa.domain.db.ApproveRecord;
import cn.fw.shirasawa.domain.enums.ApproveStateEnum;
import cn.fw.shirasawa.service.bus.follow.FollowBizService;
import cn.fw.shirasawa.service.data.ApproveRecordService;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.apache.rocketmq.spring.annotation.RocketMQMessageListener;
import org.apache.rocketmq.spring.core.RocketMQListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Objects;

/**
 * @author : kurisu
 * Date: 2020/9/16
 * Time: 10:57
 * Description:
 */
@Slf4j
@Service
@RocketMQMessageListener(topic = ApprovalResult.TOPIC, consumerGroup = "${spring.application.name}_flow_approval_result")
public class FlowConsumer implements RocketMQListener<ApprovalResult> {

    private final ApproveRecordService approveRecordService;
    private final FollowBizService followBizService;


    @Autowired
    public FlowConsumer(final ApproveRecordService approveRecordService,
                        final FollowBizService followBizService) {
        this.approveRecordService = approveRecordService;
        this.followBizService = followBizService;
    }

    @Override
    public void onMessage(ApprovalResult dto) {
        log.info("审批系统MQ消息回调：{}", JSONObject.toJSONString(dto));
        try {
            ApproveRecord record = approveRecordService.getByOrderNo(dto.getOrderNo());
            if (Objects.isNull(record)) {
                return;
            }
            onApprovalComplete(record, Boolean.TRUE.equals(dto.getAgree()));
        } catch (Exception e) {
            log.error("审批系统回调处理异常", e);
            throw e;
        }
    }

    private void onApprovalComplete(ApproveRecord record, boolean agree) {
        if (agree) {
            record.setPassed(Boolean.TRUE);
            followBizService.onApproveAgree(record.getDataId());
        }
        record.setState(ApproveStateEnum.DONE);
        approveRecordService.updateById(record);
    }
}
