package cn.fw.shirasawa.property;

import lombok.Data;
import org.springframework.boot.context.properties.ConfigurationProperties;

/**
 * 路径配置
 *
 * @author kurisu
 */
@Data
@ConfigurationProperties(prefix = "spring.url")
public class UrlProperty {

    /**
     * HTTP文件URL
     */
    private String httpFileUrl = "https://devgate.feewee.cn/file";
    /**
     * HTTP文件预览路径
     */
    private String httpShowFilePath = "/show?fid=";
    /**
     * HTTP文件下载路径
     */
    private String httpDownloadFilePath = "/download?fid=";

    /**
     * 获取文件预览URL
     *
     * @param fid 文件唯一识别码
     * @return 文件预览URL
     */
    public String getHttpShowUrl(final String fid) {
        return httpFileUrl + httpShowFilePath + fid;
    }

    /**
     * 获取文件下载URL
     *
     * @param fid 文件唯一识别码
     * @return 文件下载URL
     */
    public String getHttpDownloadUrl(final String fid) {
        return httpFileUrl + httpDownloadFilePath + fid;
    }

}
