package cn.fw.shirasawa.service.bus.follow.strategy.impl;

import cn.fw.shirasawa.common.utils.StringUtils;
import cn.fw.shirasawa.domain.db.OriginalData;
import cn.fw.shirasawa.domain.db.follow.FollowRecord;
import cn.fw.shirasawa.domain.db.follow.FollowTask;
import cn.fw.shirasawa.domain.db.pool.CluePool;
import cn.fw.shirasawa.domain.enums.*;
import cn.fw.shirasawa.sdk.enums.BusinessTypeEnum;
import cn.fw.shirasawa.service.bus.follow.strategy.AbstractFollowStrategy;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import lombok.Getter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;
import java.util.Objects;
import java.util.Optional;

import static cn.fw.common.businessvalidator.Validator.BV;

/**
 * @author : kurisu
 * @className : AFFollowStrategy
 * @description : 活动邀约
 * @date: 2022-01-11 15:36
 */
@Slf4j
@Component
@SuppressWarnings("Duplicates")
public class AFFollowStrategy extends AbstractFollowStrategy {
    @Value("${follow.todo.AFCode}")
    @Getter
    private String AFCode;

    @Override
    public FollowTypeEnum getFollowType() {
        return FollowTypeEnum.AF;
    }

    @Override
    public String getTodoCode() {
        return getAFCode();
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean origin2task(OriginalData originalData) throws Exception {
        List<CluePool> list = cluePoolService.list(Wrappers.<CluePool>lambdaQuery()
                .eq(CluePool::getClueType, getFollowType())
                .eq(CluePool::getCustomerId, originalData.getCustomerId())
                .eq(CluePool::getRefererId, originalData.getDetailId())
                .eq(CluePool::getGroupId, originalData.getGroupId())
                .in(CluePool::getClueStatus, ClueStatusEnum.ONGOING, ClueStatusEnum.WAITING)
        );
        if (!CollectionUtils.isEmpty(list)) {
            return true;
        }
        CluePool cluePool = transformClue(originalData);
        cluePool.setStartTime(originalData.getGenerateTime());
        LocalDateTime deadLine = Optional.ofNullable(originalData.getDeadline()).orElse(LocalDate.now().plusYears(10L).atStartOfDay());
        cluePool.setDeadline(deadLine.minusSeconds(1L));
        return cluePoolService.save(cluePool);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void startClue(CluePool cluePool) throws Exception {
        //处理重复的跟进业务
        dealRepeatClue(cluePool, this);

        FollowTask task = this.createTask(cluePool);
        boolean saveTask = followTaskService.save(task);
        BV.isTrue(saveTask, () -> "生成跟进任务失败");
        FollowRecord record = createRecord(task);
        if (StringUtils.isValid(getTodoCode())) {
            String[] todoCodeArr = getTodoCode().split(",");
            record.setTodoCode(BusinessTypeEnum.PS.equals(cluePool.getBizType()) ? todoCodeArr[0] : todoCodeArr[1]);
        }
        record.setNote(cluePool.getNote());
        record.setContacts(cluePool.getContacts());
        if (Objects.nonNull(cluePool.getFirstDeadline())) {
            record.setDeadline(cluePool.getFirstDeadline());
        }
        followRecordService.save(record);

        if (OutTimeEnum.BE_SYSTEM.equals(record.getOutTime())) {
            //状态处理 存在已完成的活动跟进 直接当前跟进已完成
            cluePool.setClueStatus(ClueStatusEnum.COMPLETE);
            task.setState(TaskStateEnum.COMPLETE);
            followTaskService.updateById(task);
        } else {
            cluePool.setClueStatus(ClueStatusEnum.ONGOING);
        }
        cluePoolService.updateById(cluePool);
    }
}
