package cn.fw.shirasawa.service.data;

import cn.fw.shirasawa.domain.db.pool.CluePool;
import cn.fw.shirasawa.domain.dto.CluePoolDTO;
import cn.fw.shirasawa.domain.enums.FollowTypeEnum;
import cn.fw.shirasawa.domain.query.CluePoolQueryVO;
import com.baomidou.mybatisplus.extension.service.IService;
import org.springframework.lang.Nullable;

import java.util.List;

/**
 * @author : kurisu
 * @className : CustomerCluePoolService
 * @description : 客户线索池
 * @date: 2020-11-12 09:35
 */
public interface CluePoolService extends IService<CluePool> {
    /**
     * 通过refererId查询线索
     *
     * @param refererId
     * @param groupId
     * @param type
     * @return
     */
    @Nullable
    CluePool queryByRefererId(String refererId, Long groupId, FollowTypeEnum type);

    /**
     * 通过vin查询线索
     *
     * @param vin
     * @param groupId
     * @param type
     * @return
     */
    @Nullable
    CluePool queryByVin(String vin, Long groupId, FollowTypeEnum type);

    /**
     * 通过车牌号查询线索
     *
     * @param plateNo
     * @param groupId
     * @param type
     * @return
     */
    @Nullable
    CluePool queryByPlateNo(String plateNo, Long groupId, FollowTypeEnum type);

    /**
     * 查询客户线索池
     *
     * @param queryVO
     * @return
     */
    List<CluePoolDTO> clueList(CluePoolQueryVO queryVO);

    /**
     * 总数
     *
     * @param queryVO
     * @return
     */
    Long clueListCount(CluePoolQueryVO queryVO);

    /**
     * 成交数
     *
     * @param queryVO
     * @return
     */
    Long completeNum(CluePoolQueryVO queryVO);

    /**
     * 战败数
     *
     * @param queryVO
     * @return
     */
    Long defeatNum(CluePoolQueryVO queryVO);

    /**
     * 进行中的数量
     *
     * @param queryVO
     * @return
     */
    Long onGoingNum(CluePoolQueryVO queryVO);
}
