package cn.fw.shirasawa.service.data.impl;

import cn.fw.shirasawa.dao.mapper.CluePoolMapper;
import cn.fw.shirasawa.domain.db.pool.CluePool;
import cn.fw.shirasawa.domain.dto.CluePoolDTO;
import cn.fw.shirasawa.domain.enums.FollowTypeEnum;
import cn.fw.shirasawa.domain.query.CluePoolQueryVO;
import cn.fw.shirasawa.service.data.CluePoolService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.lang.Nullable;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

/**
 * @author : kurisu
 * @className : CustomerCluePoolServiceImpl
 * @description : 线索池
 * @date: 2020-11-12 09:36
 */
@Service
public class CluePoolServiceImpl extends ServiceImpl<CluePoolMapper, CluePool> implements CluePoolService {
    @Override
    @Nullable
    public CluePool queryByRefererId(String refererId, Long groupId, FollowTypeEnum type) {
        return getOne(Wrappers.<CluePool>lambdaQuery()
                .eq(CluePool::getRefererId, refererId)
                .eq(CluePool::getGroupId, groupId)
                .eq(CluePool::getClueType, type)
                .orderByDesc(CluePool::getId)
                .last(" limit 1")
        );
    }

    @Override
    @Nullable
    public CluePool queryByVin(String vin, Long groupId, FollowTypeEnum type) {
        return getOne(Wrappers.<CluePool>lambdaQuery()
                .eq(CluePool::getFrameNo, vin)
                .eq(CluePool::getGroupId, groupId)
                .eq(CluePool::getClueType, type)
                .orderByDesc(CluePool::getId)
                .last(" limit 1")
        );
    }

    @Override
    @Nullable
    public CluePool queryByPlateNo(String plateNo, Long groupId, FollowTypeEnum type) {
        return getOne(Wrappers.<CluePool>lambdaQuery()
                .eq(CluePool::getPlateNo, plateNo)
                .eq(CluePool::getGroupId, groupId)
                .eq(CluePool::getClueType, type)
                .orderByDesc(CluePool::getId)
                .last(" limit 1")
        );
    }

    @Override
    public List<CluePoolDTO> clueList(CluePoolQueryVO queryVO) {
        Integer current = queryVO.getCurrent();
        Integer pageSize = queryVO.getPageSize();
        Integer startIndex = (current - 1) * pageSize;
        return Optional.ofNullable(getBaseMapper().clueList(startIndex, pageSize, queryVO)).orElse(new ArrayList<>());
    }

    @Override
    public Long clueListCount(CluePoolQueryVO queryVO) {
        return Optional.ofNullable(getBaseMapper().clueListCount(queryVO)).orElse(0L);
    }

    @Override
    public Long completeNum(CluePoolQueryVO queryVO) {
        return Optional.ofNullable(getBaseMapper().completeNum(queryVO)).orElse(0L);
    }

    @Override
    public Long defeatNum(CluePoolQueryVO queryVO) {
        return Optional.ofNullable(getBaseMapper().defeatNum(queryVO)).orElse(0L);
    }

    @Override
    public Long onGoingNum(CluePoolQueryVO queryVO) {
        return Optional.ofNullable(getBaseMapper().onGoingNum(queryVO)).orElse(0L);
    }
}
